**Main author:** Adrian Price-Whelan (`@adrn <https://github.com/adrn>`_)

All contributors (alphabetical last name):

* Bill Chen (@ybillchen)
* Dan Foreman-Mackey (@dfm)
* Nico Garavito-Camargo (@jngaravitoc)
* Johnny Greco (@johnnygreco)
* Akeem Hart (@akeemlh)
* Sergey Koposov (@segasai)
* Alex Kurek (@AlexKurek)
* Daniel Lenz (@DanielLenz)
* Zhaozhou Li (@syrte)
* Sophia Lilleengen (@sophialilleengen)
* Pey Lian Lim (@pllim)
* Semyeong Oh (@smoh)
* Clément Robert (@neutrinoceros)
* Brigitta Sipőcz (@bsipocz)
* Harrison Souchereau (@HSouch)
* Nathaniel Starkman (@nstarman)
* Tom Wagg (@tomwagg)
